Enum SpecialRustType

#[non_exhaustive]
pub enum SpecialRustType {
Show 23 variants Vec(Box<RustType>), Array(Box<RustType>, usize), Slice(Box<RustType>), HashMap(Box<RustType>, Box<RustType>), Option(Box<RustType>), Unit, String, Char, I8, I16, I32, I64, U8, U16, U32, U64, ISize, USize, Bool, F32, F64, I54, U53,
}
A special rust type that needs a manual type conversion

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Vec(Box<RustType>)

Represents Vec<T> from the standard library



Array(Box<RustType>, usize)

Represents [T; N] from the standard library



Slice(Box<RustType>)

Represents &[T] from the standard library



HashMap(Box<RustType>, Box<RustType>)

Represents HashMap<K, V> from the standard library



Option(Box<RustType>)

Represents Option<T> from the standard library



Unit

Represents ()



String

Represents String from the standard library



Char

Represents char



I8

Represents i8



I16

Represents i16



I32

Represents i32



I64

Represents i64



U8

Represents u8



U16

Represents u16



U32

Represents u32



U64

Represents u64



ISize

Represents isize



USize

Represents usize



Bool

Represents bool



F32

Represents f32



F64

Represents f64



I54

Represents I54 from typeshare::I54



U53

Represents U53 from typeshare::U53

Implementations

Source

impl SpecialRustType

pub fn contains_type(&self, ty: &TypeName) -> bool

Check if this type is equivalent to or contains ty in one of its generic parameters. This only operates on “externally named” types; (that is, types that aren’t primitives) because it’s used only to detect the presence of generics, or that a type is recursive, or anything like that. It always returns false for things like ints and strings.

pub fn parameters(&self) -> Box<dyn Iterator<Item = &RustType> + '_>

Iterate over the generic parameters for this type. Returns an empty iterator if there are none.