pub struct CrateName(/* private fields */);Expand description
A crate name.
Implementations
Sourceimpl CrateName
impl CrateName
pub const fn new(name: String) -> Self
Sourcepub fn find_crate_name(path: &Path) -> Option<Self>
pub fn find_crate_name(path: &Path) -> Option<Self>
Extract the crate name from a give path to a rust source file. This is
defined as the name of the directory one level above the src directory
that cotains this source file, with any - replaced with _.