pub struct RustField {
pub id: Id,
pub ty: RustType,
pub comments: Vec<String>,
pub has_default: bool,
pub decorators: DecoratorSet,
}Expand description
Rust field definition.
Fields
id: IdIdentifier for the field.
ty: RustTypeType of the field.
comments: Vec<String>Comments that were in the original source.
has_default: boolThis will be true if the field has a serde(default) decorator.
Even if the field’s type is not optional, we need to make it optional
for the languages we generate code for.
decorators: DecoratorSetLanguage-specific decorators assigned to a given field. The keys are language names (e.g. SupportedLanguage::TypeScript), the values are field decorators (e.g. readonly)