pub struct RustStruct {
pub id: Id,
pub generic_types: Vec<TypeName>,
pub fields: Vec<RustField>,
pub comments: Vec<String>,
pub decorators: DecoratorSet,
}Expand description
Rust struct.
Fields
id: IdThe identifier for the struct.
generic_types: Vec<TypeName>The generic parameters that come after the struct name.
fields: Vec<RustField>The fields of the struct.
comments: Vec<String>Comments that were in the struct source. We copy comments over to the typeshared files, so we need to collect them here.
decorators: DecoratorSetAttributes that exist for this struct.