pub struct RustTypeAlias {
pub id: Id,
pub generic_types: Vec<TypeName>,
pub ty: RustType,
pub comments: Vec<String>,
}Expand description
Rust type alias.
pub struct MasterPassword(String);Fields
id: IdThe identifier for the alias.
generic_types: Vec<TypeName>The generic parameters that come after the type alias name.
ty: RustTypeThe type identifier that this type alias is aliasing
comments: Vec<String>Comments that were in the type alias source.