pub struct RustEnumShared {
pub id: Id,
pub generic_types: Vec<TypeName>,
pub comments: Vec<String>,
pub decorators: DecoratorSet,
pub is_recursive: bool,
}Expand description
Enum information shared among different enum types
Fields
id: IdThe enum’s ident
generic_types: Vec<TypeName>Generic parameters for the enum, e.g. SomeEnum<T> would produce vec!["T"]
comments: Vec<String>Comments on the enum definition itself
decorators: DecoratorSetDecorators applied to the enum for generation in other languages
Example: #[typeshare(swift = "Equatable, Comparable, Hashable")].
is_recursive: boolTrue if this enum references itself in any field of any variant
Swift needs the special keyword indirect for this case