Struct RustField

pub struct RustField {
    pub id: Id,
    pub ty: RustType,
    pub comments: Vec<String>,
    pub has_default: bool,
    pub decorators: DecoratorSet,
}
Rust field definition.

Fields

id: Id

Identifier for the field.

ty: RustType

Type of the field.

comments: Vec<String>

Comments that were in the original source.

has_default: bool

This will be true if the field has a serde(default) decorator. Even if the field’s type is not optional, we need to make it optional for the languages we generate code for.

decorators: DecoratorSet

Language-specific decorators assigned to a given field. The keys are language names (e.g. SupportedLanguage::TypeScript), the values are field decorators (e.g. readonly)